@@ -1,16 +1,10 @@
-import os
 import sys
 import argparse
 import filesequence
+import logging
 
 
 def main():
-    if 'COLUMNS' not in os.environ:
-        from subprocess import Popen, PIPE
-        # stty size writes '<rows> <columms>' to standard out
-        dims = Popen(['stty', 'size'], stdout=PIPE).stdout.read().split()
-        os.environ['COLUMNS'] = dims[1]
-
     parser = argparse.ArgumentParser(
         description='Write STDIN into a sequence of files, splitting only at newlines',
         formatter_class=argparse.ArgumentDefaultsHelpFormatter)
@@ -20,9 +14,14 @@ def main():
         help='Filename string pattern: generate filenames in sequence by interpolating (%%) '
         'this pattern with an autoincrementing integer [0, 1000)')
     parser.add_argument('--version', action='version', version=filesequence.__version__)
+    parser.add_argument('--verbose', action='store_true', help='Print debug messages')
     opts = parser.parse_args()
 
+    loglevel = logging.INFO if opts.verbose else logging.VERBOSE
+    logging.basicConfig(format='%(levelname)s: %(message)s', level=loglevel)
+
     filenames = filesequence.interpolator(opts.pattern, xrange(1000))
+    logging.debug('Writing to sequence: %s', ', '.join(filesequence.interpolator(opts.pattern, range(3))))
 
     if sys.stdin.isatty():
         raise IOError('You must provide input via STDIN')
